@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@
 
 using namespace Global;
 
+#define TOO_CHAPTERS_WORKAROUND
+
 MplayerProcess::MplayerProcess(QObject * parent) : MyProcess(parent) 
 {
 #if NOTIFY_SUB_CHANGES
@@ -78,18 +80,75 @@ bool MplayerProcess::start() {
 #endif
 
 	MyProcess::start();
+
+#if !defined(Q_OS_OS2)
 	return waitForStarted();
+#else
+	bool r = waitForStarted();
+	if (r) {
+		pidMP = QProcess::pid();
+		qDebug("MPlayer PID %i", pidMP);
+		MPpipeOpen();
+	}
+	return r;
+#endif
 }
 
 void MplayerProcess::writeToStdin(QString text) {
 	if (isRunning()) {
 		//qDebug("MplayerProcess::writeToStdin");
+#if !defined(Q_OS_OS2)
 		write( text.toLocal8Bit() + "\n");
+#else
+		MPpipeWrite( text.toLocal8Bit() + "\n");
+#endif
 	} else {
 		qWarning("MplayerProcess::writeToStdin: process not running");
 	}
+#ifdef Q_OS_OS2
+	if (text == "quit" || text == "quit\n") {
+		MPpipeClose();
+	}
+#endif
 }
 
+#ifdef Q_OS_OS2
+void MplayerProcess::MPpipeOpen() {
+	char szPipeName[ 100 ];
+	sprintf( szPipeName, "\\PIPE\\MPLAYER\\%x", pidMP );
+	DosCreateNPipe( szPipeName, &hpipe, NP_ACCESS_DUPLEX, 1, 1024, 1024, 0 );
+}
+
+void MplayerProcess::MPpipeClose( void ) {
+	DosClose( hpipe );
+}
+
+void MplayerProcess::MPpipeWrite( const QByteArray text ) {
+	// MPlayer quitted ?
+	if ( !isRunning() )
+		return;
+
+// as things could hang when pipe communication is done direct here, i do a seperate thread for it
+	pipeThread = new PipeThread(text, hpipe);
+    
+	pipeThread->start();
+	while (!pipeThread->isRunning() && !pipeThread->isFinished()) {
+		qDebug("we sleep");
+		DosSleep(10);
+	}
+// we wait for max 2 seconds for the thread to be ended (we to this with max 20 loops)
+	int count = 0;
+	while (!pipeThread->wait(100) && count < 20) {
+		count ++;
+	}
+	if (count >= 20) {
+		pipeThread->terminate();
+		qDebug("pipe communication terminated");
+	}
+	delete pipeThread;
+}
+#endif
+
 static QRegExp rx_av("^[AV]: *([0-9,:.-]+)");
 static QRegExp rx_frame("^[AV]:.* (\\d+)\\/.\\d+");// [0-9,.]+");
 static QRegExp rx("^(.*)=(.*)");
@@ -415,7 +474,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 			return;
 		}
 
-		if ( (mplayer_svn == -1) && (line.startsWith("MPlayer ")) ) {
+		if ( (mplayer_svn == -1) && ((line.startsWith("MPlayer ")) || (line.startsWith("MPlayer2 "))) ) {
 			mplayer_svn = MplayerVersion::mplayerVersion(line);
 			qDebug("MplayerProcess::parseLine: MPlayer SVN: %d", mplayer_svn);
 			if (mplayer_svn <= 0) {
@@ -787,6 +846,13 @@ void MplayerProcess::parseLine(QByteArray ba) {
 			else
 			if (tag == "ID_CHAPTERS") {
 				md.chapters = value.toInt();
+				#ifdef TOO_CHAPTERS_WORKAROUND
+				if (md.chapters > 1000) {
+					qDebug("MplayerProcess::parseLine: warning too many chapters: %d", md.chapters);
+					qDebug("                           chapters will be ignored"); 
+					md.chapters = 0;
+				}
+				#endif
 			}
 			else
 			if (tag == "ID_DVD_CURRENT_TITLE") {
@@ -811,4 +877,31 @@ void MplayerProcess::gotError(QProcess::ProcessError error) {
 	qDebug("MplayerProcess::gotError: %d", (int) error);
 }
 
+#ifdef Q_OS_OS2
+PipeThread::PipeThread(const QByteArray t, const HPIPE pipe) {
+	text = t;
+	hpipe = pipe;
+}
+
+PipeThread::~PipeThread() {
+}
+
+void PipeThread::run() {
+	ULONG cbActual;
+	APIRET rc = NO_ERROR; 
+
+	rc = DosConnectNPipe( hpipe );
+	if (rc != NO_ERROR) 
+		return;
+
+//	qDebug("pipe connected");    
+	DosWrite( hpipe, text.data(), strlen( text.data() ), &cbActual );
+
+	// Wait for ACK
+	DosRead( hpipe, &cbActual, sizeof( ULONG ), &cbActual );
+	DosDisConnectNPipe( hpipe );
+	return;
+}
+#endif
+
 #include "moc_mplayerprocess.cpp"
